@@ -3,12 +3,11 @@ import numpy as np
 from sklearn import metrics
 from sklearn.model_selection import GridSearchCV
 from sklearn.preprocessing import StandardScaler
-from sklearn.svm import LinearSVC, LinearSVR, SVC
-from sklearn.model_selection import GridSearchCV, KFold, RepeatedKFold
+from sklearn.svm import LinearSVR, SVC
+from sklearn.model_selection import GridSearchCV, RepeatedKFold
 from sklearn.utils._testing import ignore_warnings
 from sklearn.exceptions import ConvergenceWarning
 
-
 def train_initialize(df, k, n_repeats, param_grid):
   folds = [(train, test) for (train, test) in RepeatedKFold(n_splits=k, n_repeats=n_repeats, random_state=2022).split(df['PTID'])]
   scaler = [StandardScaler()] * len(folds)
@@ -86,4 +85,4 @@ def run_SVR(df, predictors, to_predict, param_grid, k=5, n_repeats=1, verbose=1)
   if verbose==1:
     print('>> MAE =', np.round(np.mean(mae), 3), '+/-', np.round(np.std(mae), 3))
 
-  return y_hat, {'mdl':mdl, 'scaler':scaler, 'bias_correct':bias_correct, 'cv_folds':folds}, mae, params
+  return y_hat, {'mdl':mdl, 'scaler':scaler, 'bias_correct':bias_correct, 'cv_folds':folds}, mae, params
\ No newline at end of file
